@@ -15,8 +15,7 @@ def VacancyAnalysis():
         os.makedirs(os.path.join(base, sub), exist_ok=True)
 
     
-    processor = TrainingProcessor()
-    processor.run()
+
 
     
     CONFIG = cargar_json_usuario()
@@ -31,7 +30,9 @@ def VacancyAnalysis():
     cs_generator = CrystalStructureGenerator(configuracion, cs_out_dir)
     dump_path = cs_generator.generate()
     print(f"Estructura relajada generada en: {dump_path}")
-
+    if configuracion['training']:
+        processor = TrainingProcessor()
+        processor.run()
     processor = ClusterProcessor(defect_file)
     processor.run()
     separator = KeyFilesSeparator(configuracion, os.path.join("outputs/json", "clusters.json"))
@@ -74,16 +75,52 @@ def VacancyAnalysis():
     exporter.export()
 
 
-    #Calcular categoria de defect_file.csv
-    model = BehaviorTreeModel(weight_cluster_size=2.0, max_depth=5)
-    model.train('outputs/json/training_graph.json')
+    # ------------------------------------------------------------------------
+    # 8. Entrenar y clasificar defectos con el nuevo modelo ensemble
 
-    df_resultado = model.classify_csv(
+    # Instancia y entrena el modelo
+    clf = ImprovedVacancyClassifier(json_path='outputs/json/training_graph.json')
+    clf.train()  
+    # → ya imprime mejores parámetros y reporte de clasificación
+
+    # Clasifica tu CSV de defectos (añade columna 'grupo_predicho')
+    df_clasif = clf.classify_csv(
         csv_path='outputs/csv/defect_data.csv',
         output_path='outputs/csv/finger_data_clasificado.csv'
     )
+    print(df_clasif[['archivo','grupo_predicho']])
+    # ------------------------------------------------------------------------
+    # 9. Predicción de vacancias según grupo_predicho
+    # Como ImprovedVacancyClassifier usa la misma API de train/classify,
+    # podemos reusar el método classify_csv para predecir vacancias
+    # (o bien, si lo prefieres, crear un método predict_from_csv
+    #  similar al anterior)
+    df_pred = clf.classify_csv(
+        csv_path='outputs/csv/finger_data_clasificado.csv',
+        output_path='outputs/csv/finger_data_predicha.csv'
+    )
+    print("✅ Vacancias predichas guardadas en outputs/csv/finger_data_predicha.csv")
 
-    print(df_resultado[['archivo', 'grupo_predicho']])
+    # ------------------------------------------------------------------------
+    # 10. Continuar con el resto de tu pipeline
+    assigner = FingerprintVacancyAssigner(
+        base_csv_path="outputs/csv/finger_data.csv",
+        query_csv_path="outputs/csv/finger_key_files.csv",
+        weight_N=1
+    )
+    df_result = assigner.assign()
+    df_result.to_csv("outputs/csv/finger_key_files_clasificado.csv", index=False)
+    print("✅ Resultado guardado con peso_N =", assigner.weight_N)
+    #Calcular categoria de defect_file.csv
+    #model = BehaviorTreeModel(weight_cluster_size=2.0, max_depth=5)
+    #model.train('outputs/json/training_graph.json')
+
+    #df_resultado = model.classify_csv(
+     #   csv_path='outputs/csv/defect_data.csv',
+      #  output_path='outputs/csv/finger_data_clasificado.csv'
+    #)
+
+    #print(df_resultado[['archivo', 'grupo_predicho']])
 
 
     #ETAPA DE PREDICCIONES
@@ -94,11 +131,17 @@ def VacancyAnalysis():
     trainer.train_all_models()
     #
     #  Predecir en lote desde archivo CSV
+    # Supongamos que en la etapa anterior guardaste:
+    # outputs/csv/finger_data_clasificado.csv
+    df_pred = trainer.predict_from_csv('outputs/csv/finger_data_clasificado.csv')
+    df_pred.to_csv('outputs/csv/finger_data_predicha.csv', index=False)
+    print("✅ Vacancias predichas guardadas en outputs/csv/finger_data_predicha.csv")
+
 # Ejemplo de uso
     assigner = FingerprintVacancyAssigner(
         base_csv_path="outputs/csv/finger_data.csv",
         query_csv_path="outputs/csv/finger_key_files.csv",
-        weight_N=2 # peso mayor para 'N'
+        weight_N=.5 # peso mayor para 'N'
     )
     df_result = assigner.assign()
     df_result.to_csv("outputs/csv/finger_key_files_clasificado.csv", index=False)
